==> l7-layers-2.9.23.tgz: package/lib/tile/manager/tileLayerManager.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target, mod));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/tile/manager/tileLayerManager.ts
var tileLayerManager_exports = {};
__export(tileLayerManager_exports, {
  TileLayerManager: () => TileLayerManager
});
module.exports = __toCommonJS(tileLayerManager_exports);
var import_l7_utils = require("@antv/l7-utils");
var import_tileFactory = require("../tileFactory");
var import_utils = require("../utils");
var import_tileConfigManager = __toESM(require("./tileConfigManager"));
var import_tilePickerManager = __toESM(require("./tilePickerManager"));
var TileLayerManager = class {
  constructor(parent, mapService, rendererService, pickingService, layerService) {
    this.parent = parent;
    this.children = parent.layerChildren;
    this.mapService = mapService;
    this.rendererService = rendererService;
    this.tilePickManager = new import_tilePickerManager.default(parent, rendererService, pickingService, this.children, layerService);
    this.tileConfigManager = new import_tileConfigManager.default();
    this.setSubLayerInitOptipn();
    this.setConfigListener();
    this.initTileFactory();
  }
  createTile(tile) {
    return this.tileFactory.createTile(tile, this.initOptions);
  }
  updateLayersConfig(layers, key, value) {
    layers.map((layer) => {
      if (key === "mask") {
        layer.style({
          mask: value
        });
      } else {
        layer.updateLayerConfig({
          [key]: value
        });
      }
    });
  }
  addChild(layer) {
    this.children.push(layer);
  }
  addChilds(layers) {
    this.children.push(...layers);
  }
  removeChilds(layerIDList, refresh = true) {
    const remveLayerList = [];
    const cacheLayerList = [];
    this.children.filter((child) => {
      layerIDList.includes(child.id) ? remveLayerList.push(child) : cacheLayerList.push(child);
    });
    remveLayerList.map((layer) => layer.destroy(refresh));
    this.children = cacheLayerList;
  }
  removeChild(layer) {
    const layerIndex = this.children.indexOf(layer);
    if (layerIndex > -1) {
      this.children.splice(layerIndex, 1);
    }
    layer.destroy();
  }
  getChilds(layerIDList) {
    return this.children.filter((child) => layerIDList.includes(child.id));
  }
  getChild(layerID) {
    return this.children.filter((child) => child.id === layerID)[0];
  }
  clearChild() {
    this.children.forEach((layer) => {
      layer.destroy();
    });
    this.children.slice(0, this.children.length);
  }
  hasChild(layer) {
    return this.children.includes(layer);
  }
  render() {
    var _a, _b;
    (_a = this.tileConfigManager) == null ? void 0 : _a.checkConfig(this.parent);
    (_b = this.tilePickManager) == null ? void 0 : _b.normalRender(this.children);
  }
  pickLayers(target) {
    var _a;
    return (_a = this.tilePickManager) == null ? void 0 : _a.pickRender(this.children, target);
  }
  setSubLayerInitOptipn() {
    var _a;
    const {
      zIndex = 0,
      opacity = 1,
      mask = false,
      stroke = "#fff",
      strokeWidth = 0,
      strokeOpacity = 1,
      clampLow = true,
      clampHigh = true,
      domain = [0, 1],
      rampColors = {
        colors: [
          "rgb(166,97,26)",
          "rgb(223,194,125)",
          "rgb(245,245,245)",
          "rgb(128,205,193)",
          "rgb(1,133,113)"
        ],
        positions: [0, 0.25, 0.5, 0.75, 1]
      },
      featureId = "id",
      workerEnabled = false,
      sourceLayer,
      pixelConstant = 0,
      pixelConstantR = 256 * 256,
      pixelConstantG = 256,
      pixelConstantB = 1,
      pixelConstantRGB = 0.1
    } = this.parent.getLayerConfig();
    const colorValue = this.tileConfigManager.getAttributeScale(this.parent, "color");
    const sizeValue = this.tileConfigManager.getAttributeScale(this.parent, "size");
    const source = this.parent.getSource();
    const { coords } = ((_a = source == null ? void 0 : source.data) == null ? void 0 : _a.tilesetOptions) || {};
    const layerShape = (0, import_utils.getLayerShape)(this.parent.type, this.parent);
    if (rampColors) {
      this.rampColorsData = (0, import_l7_utils.generateColorRamp)(rampColors);
    }
    this.initOptions = {
      layerType: this.parent.type,
      shape: layerShape,
      zIndex,
      opacity,
      sourceLayer,
      coords,
      featureId,
      color: colorValue,
      size: sizeValue,
      mask: (0, import_utils.getMaskValue)(this.parent.type, mask),
      stroke,
      strokeWidth,
      strokeOpacity,
      clampLow,
      clampHigh,
      domain,
      rampColors,
      rampColorsData: this.rampColorsData,
      workerEnabled,
      pixelConstant,
      pixelConstantR,
      pixelConstantG,
      pixelConstantB,
      pixelConstantRGB
    };
  }
  setConfigListener() {
    var _a, _b, _c;
    this.tileConfigManager.setConfig("opacity", this.initOptions.opacity);
    this.tileConfigManager.setConfig("zIndex", this.initOptions.zIndex);
    this.tileConfigManager.setConfig("mask", this.initOptions.mask);
    if (this.parent.type === "RasterLayer") {
      this.tileConfigManager.setConfig("rampColors", this.initOptions.rampColors);
      this.tileConfigManager.setConfig("domain", this.initOptions.domain);
      this.tileConfigManager.setConfig("clampHigh", this.initOptions.clampHigh);
      this.tileConfigManager.setConfig("clampLow", this.initOptions.clampLow);
      this.tileConfigManager.setConfig("pixelConstant", this.initOptions.pixelConstant);
      this.tileConfigManager.setConfig("pixelConstantR", this.initOptions.pixelConstantR);
      this.tileConfigManager.setConfig("pixelConstantG", this.initOptions.pixelConstantG);
      this.tileConfigManager.setConfig("pixelConstantB", this.initOptions.pixelConstantB);
      this.tileConfigManager.setConfig("pixelConstantRGB", this.initOptions.pixelConstantRGB);
    } else {
      this.tileConfigManager.setConfig("stroke", this.initOptions.stroke);
      this.tileConfigManager.setConfig("strokeWidth", this.initOptions.strokeWidth);
      this.tileConfigManager.setConfig("strokeOpacity", this.initOptions.strokeOpacity);
      this.tileConfigManager.setConfig("color", (_a = this.parent.getAttribute("color")) == null ? void 0 : _a.scale);
      this.tileConfigManager.setConfig("shape", (_b = this.parent.getAttribute("shape")) == null ? void 0 : _b.scale);
      this.tileConfigManager.setConfig("size", (_c = this.parent.getAttribute("size")) == null ? void 0 : _c.scale);
    }
    this.tileConfigManager.on("updateConfig", (updateConfigs) => {
      updateConfigs.map((key) => {
        this.updateStyle(key);
        return "";
      });
    });
  }
  updateStyle(style) {
    var _a;
    let updateValue = null;
    if (["size", "color", "shape"].includes(style)) {
      const scaleValue = (_a = this.parent.getAttribute(style)) == null ? void 0 : _a.scale;
      if (!scaleValue) {
        return;
      }
      updateValue = scaleValue;
      this.children.map((child) => {
        this.tileFactory.setStyleAttributeField(child, style, scaleValue);
        return "";
      });
    } else {
      const layerConfig = this.parent.getLayerConfig();
      if (!(style in layerConfig)) {
        return;
      }
      const config = layerConfig[style];
      updateValue = config;
      this.updateLayersConfig(this.children, style, config);
      if (style === "rampColors" && config) {
        this.rampColorsData = (0, import_l7_utils.generateColorRamp)(config);
      }
    }
    this.initOptions[style] = updateValue;
  }
  initTileFactory() {
    const source = this.parent.getSource();
    const TileFactory = (0, import_tileFactory.getTileFactory)(this.parent.type, source.parser);
    this.tileFactory = new TileFactory({
      parent: this.parent,
      mapService: this.mapService,
      rendererService: this.rendererService
    });
  }
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  TileLayerManager
});

==> l7-layers-2.9.24.tgz: package/lib/tile/manager/tileLayerManager.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target, mod));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/tile/manager/tileLayerManager.ts
var tileLayerManager_exports = {};
__export(tileLayerManager_exports, {
  TileLayerManager: () => TileLayerManager
});
module.exports = __toCommonJS(tileLayerManager_exports);
var import_l7_utils = require("@antv/l7-utils");
var import_tileFactory = require("../tileFactory");
var import_utils = require("../utils");
var import_tileConfigManager = __toESM(require("./tileConfigManager"));
var import_tilePickerManager = __toESM(require("./tilePickerManager"));
var TileLayerManager = class {
  constructor(parent, mapService, rendererService, pickingService, layerService, transforms) {
    this.parent = parent;
    this.children = parent.layerChildren;
    this.mapService = mapService;
    this.rendererService = rendererService;
    this.transforms = transforms;
    this.tilePickManager = new import_tilePickerManager.default(parent, rendererService, pickingService, this.children, layerService);
    this.tileConfigManager = new import_tileConfigManager.default();
    this.setSubLayerInitOptipn();
    this.setConfigListener();
    this.initTileFactory();
  }
  createTile(tile) {
    return this.tileFactory.createTile(tile, this.initOptions);
  }
  updateLayersConfig(layers, key, value) {
    layers.map((layer) => {
      if (key === "mask") {
        layer.style({
          mask: value
        });
      } else {
        layer.updateLayerConfig({
          [key]: value
        });
      }
    });
  }
  addChild(layer) {
    this.children.push(layer);
  }
  addChilds(layers) {
    this.children.push(...layers);
  }
  removeChilds(layerIDList, refresh = true) {
    const remveLayerList = [];
    const cacheLayerList = [];
    this.children.filter((child) => {
      layerIDList.includes(child.id) ? remveLayerList.push(child) : cacheLayerList.push(child);
    });
    remveLayerList.map((layer) => layer.destroy(refresh));
    this.children = cacheLayerList;
  }
  removeChild(layer) {
    const layerIndex = this.children.indexOf(layer);
    if (layerIndex > -1) {
      this.children.splice(layerIndex, 1);
    }
    layer.destroy();
  }
  getChilds(layerIDList) {
    return this.children.filter((child) => layerIDList.includes(child.id));
  }
  getChild(layerID) {
    return this.children.filter((child) => child.id === layerID)[0];
  }
  clearChild() {
    this.children.forEach((layer) => {
      layer.destroy();
    });
    this.children.slice(0, this.children.length);
  }
  hasChild(layer) {
    return this.children.includes(layer);
  }
  render() {
    var _a, _b;
    (_a = this.tileConfigManager) == null ? void 0 : _a.checkConfig(this.parent);
    (_b = this.tilePickManager) == null ? void 0 : _b.normalRender(this.children);
  }
  pickLayers(target) {
    var _a;
    return (_a = this.tilePickManager) == null ? void 0 : _a.pickRender(this.children, target);
  }
  setSubLayerInitOptipn() {
    var _a;
    const {
      zIndex = 0,
      opacity = 1,
      mask = false,
      stroke = "#fff",
      strokeWidth = 0,
      strokeOpacity = 1,
      clampLow = true,
      clampHigh = true,
      domain = [0, 1],
      rampColors = {
        colors: [
          "rgb(166,97,26)",
          "rgb(223,194,125)",
          "rgb(245,245,245)",
          "rgb(128,205,193)",
          "rgb(1,133,113)"
        ],
        positions: [0, 0.25, 0.5, 0.75, 1]
      },
      featureId = "id",
      workerEnabled = false,
      sourceLayer,
      pixelConstant = 0,
      pixelConstantR = 256 * 256,
      pixelConstantG = 256,
      pixelConstantB = 1,
      pixelConstantRGB = 0.1
    } = this.parent.getLayerConfig();
    const colorValue = this.tileConfigManager.getAttributeScale(this.parent, "color");
    const sizeValue = this.tileConfigManager.getAttributeScale(this.parent, "size");
    const source = this.parent.getSource();
    const { coords } = ((_a = source == null ? void 0 : source.data) == null ? void 0 : _a.tilesetOptions) || {};
    const layerShape = (0, import_utils.getLayerShape)(this.parent.type, this.parent);
    if (rampColors) {
      this.rampColorsData = (0, import_l7_utils.generateColorRamp)(rampColors);
    }
    this.initOptions = {
      layerType: this.parent.type,
      transforms: this.transforms,
      shape: layerShape,
      zIndex,
      opacity,
      sourceLayer,
      coords,
      featureId,
      color: colorValue,
      size: sizeValue,
      mask: (0, import_utils.getMaskValue)(this.parent.type, mask),
      stroke,
      strokeWidth,
      strokeOpacity,
      clampLow,
      clampHigh,
      domain,
      rampColors,
      rampColorsData: this.rampColorsData,
      workerEnabled,
      pixelConstant,
      pixelConstantR,
      pixelConstantG,
      pixelConstantB,
      pixelConstantRGB
    };
  }
  setConfigListener() {
    var _a, _b, _c;
    this.tileConfigManager.setConfig("opacity", this.initOptions.opacity);
    this.tileConfigManager.setConfig("zIndex", this.initOptions.zIndex);
    this.tileConfigManager.setConfig("mask", this.initOptions.mask);
    if (this.parent.type === "RasterLayer") {
      this.tileConfigManager.setConfig("rampColors", this.initOptions.rampColors);
      this.tileConfigManager.setConfig("domain", this.initOptions.domain);
      this.tileConfigManager.setConfig("clampHigh", this.initOptions.clampHigh);
      this.tileConfigManager.setConfig("clampLow", this.initOptions.clampLow);
      this.tileConfigManager.setConfig("pixelConstant", this.initOptions.pixelConstant);
      this.tileConfigManager.setConfig("pixelConstantR", this.initOptions.pixelConstantR);
      this.tileConfigManager.setConfig("pixelConstantG", this.initOptions.pixelConstantG);
      this.tileConfigManager.setConfig("pixelConstantB", this.initOptions.pixelConstantB);
      this.tileConfigManager.setConfig("pixelConstantRGB", this.initOptions.pixelConstantRGB);
    } else {
      this.tileConfigManager.setConfig("stroke", this.initOptions.stroke);
      this.tileConfigManager.setConfig("strokeWidth", this.initOptions.strokeWidth);
      this.tileConfigManager.setConfig("strokeOpacity", this.initOptions.strokeOpacity);
      this.tileConfigManager.setConfig("color", (_a = this.parent.getAttribute("color")) == null ? void 0 : _a.scale);
      this.tileConfigManager.setConfig("shape", (_b = this.parent.getAttribute("shape")) == null ? void 0 : _b.scale);
      this.tileConfigManager.setConfig("size", (_c = this.parent.getAttribute("size")) == null ? void 0 : _c.scale);
    }
    this.tileConfigManager.on("updateConfig", (updateConfigs) => {
      updateConfigs.map((key) => {
        this.updateStyle(key);
        return "";
      });
    });
  }
  updateStyle(style) {
    var _a;
    let updateValue = null;
    if (["size", "color", "shape"].includes(style)) {
      const scaleValue = (_a = this.parent.getAttribute(style)) == null ? void 0 : _a.scale;
      if (!scaleValue) {
        return;
      }
      updateValue = scaleValue;
      this.children.map((child) => {
        this.tileFactory.setStyleAttributeField(child, style, scaleValue);
        return "";
      });
    } else {
      const layerConfig = this.parent.getLayerConfig();
      if (!(style in layerConfig)) {
        return;
      }
      const config = layerConfig[style];
      updateValue = config;
      this.updateLayersConfig(this.children, style, config);
      if (style === "rampColors" && config) {
        this.rampColorsData = (0, import_l7_utils.generateColorRamp)(config);
      }
    }
    this.initOptions[style] = updateValue;
  }
  initTileFactory() {
    const source = this.parent.getSource();
    const TileFactory = (0, import_tileFactory.getTileFactory)(this.parent.type, source.parser);
    this.tileFactory = new TileFactory({
      parent: this.parent,
      mapService: this.mapService,
      rendererService: this.rendererService
    });
  }
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  TileLayerManager
});
